user/dev discussion of public-inbox itself
 help / color / mirror / code / Atom feed
From: Eric Wong <e@80x24.org>
To: meta@public-inbox.org
Subject: [PATCH 02/38] www: gzip_filter: implicitly flush {obuf} on zmore/zflush
Date: Sat, 10 Sep 2022 08:16:53 +0000	[thread overview]
Message-ID: <20220910081729.2011934-3-e@80x24.org> (raw)
In-Reply-To: <20220910081729.2011934-1-e@80x24.org>

This seems like the least disruptive way to allow more use of
->zmore when streaming large messages to sockets.
---
 lib/PublicInbox/CompressNoop.pm | 4 ++--
 lib/PublicInbox/GzipFilter.pm   | 9 +++++----
 lib/PublicInbox/ViewVCS.pm      | 2 --
 3 files changed, 7 insertions(+), 8 deletions(-)

diff --git a/lib/PublicInbox/CompressNoop.pm b/lib/PublicInbox/CompressNoop.pm
index e3301473..5135299f 100644
--- a/lib/PublicInbox/CompressNoop.pm
+++ b/lib/PublicInbox/CompressNoop.pm
@@ -1,4 +1,4 @@
-# Copyright (C) 2020-2021 all contributors <meta@public-inbox.org>
+# Copyright (C) all contributors <meta@public-inbox.org>
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
 
 # Provide the same methods as Compress::Raw::Zlib::Deflate but
@@ -10,7 +10,7 @@ use Compress::Raw::Zlib qw(Z_OK);
 sub new { bless \(my $self), __PACKAGE__ }
 
 sub deflate { # ($self, $input, $output)
-	$_[2] .= $_[1];
+	$_[2] .= ref($_[1]) ? ${$_[1]} : $_[1];
 	Z_OK;
 }
 
diff --git a/lib/PublicInbox/ViewVCS.pm b/lib/PublicInbox/ViewVCS.pm
index 3b4fa393..ed4a6454 100644
--- a/lib/PublicInbox/ViewVCS.pm
+++ b/lib/PublicInbox/ViewVCS.pm
@@ -210,8 +210,6 @@ EOM
 		$x =~ s/\r?\n/\n/gs;
 		$ctx->{-anchors} = {} if $x =~ /^diff --git /sm;
 		flush_diff($ctx, \$x); # undefs $x
-		$ctx->zmore($bdy);
-		undef $bdy;
 		# TODO: should there be another textarea which attempts to
 		# search for the exact email which was applied to make this
 		# commit?

  parent reply	other threads:[~2022-09-10  8:18 UTC|newest]

Thread overview: 39+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-09-10  8:16 [PATCH 00/38] www: reduce memory usage Eric Wong
2022-09-10  8:16 ` [PATCH 01/38] xt: fold perf-obfuscate into perf-msgview, future-proof Eric Wong
2022-09-10  8:16 ` Eric Wong [this message]
2022-09-10  8:16 ` [PATCH 03/38] view: rework single message page to compress earlier Eric Wong
2022-09-10  8:16 ` [PATCH 04/38] www_atom_stream: require 200 response Eric Wong
2022-09-10  8:16 ` [PATCH 05/38] www_stream: aresponse assumes 200, too Eric Wong
2022-09-10  8:16 ` [PATCH 06/38] www_text: reduce parameter passing for response header Eric Wong
2022-09-10  8:16 ` [PATCH 07/38] viewvcs: use shorter and simpler ctx->html_done Eric Wong
2022-09-10  8:16 ` [PATCH 08/38] www_listing: consolidate some ->zmore dispatches Eric Wong
2022-09-10  8:17 ` [PATCH 09/38] www_listing: avoid unnecessary work for common cases Eric Wong
2022-09-10  8:17 ` [PATCH 10/38] www: viewdiff: use return value for diff_hunk Eric Wong
2022-09-10  8:17 ` [PATCH 11/38] view: simplify _parent_headers Eric Wong
2022-09-10  8:17 ` [PATCH 12/38] view: eml_entry: reduce manipulation of ctx->{obuf} Eric Wong
2022-09-10  8:17 ` [PATCH 13/38] gzip_filter: ->translate can reuse zmore/zflush Eric Wong
2022-09-10  8:17 ` [PATCH 14/38] view: remove multipart_text_as_html Eric Wong
2022-09-10  8:17 ` [PATCH 15/38] view: reduce subroutine calls for submsg_hdr Eric Wong
2022-09-10  8:17 ` [PATCH 16/38] view: attach_link: reduce obuf manipulation Eric Wong
2022-09-10  8:17 ` [PATCH 17/38] viewdiff: reuse existing string in diff_before_or_after Eric Wong
2022-09-10  8:17 ` [PATCH 18/38] view: _th_index_lite: avoid one s///, improve symmetry Eric Wong
2022-09-10  8:17 ` [PATCH 19/38] view: _th_index_lite: use `//' defined-or op Eric Wong
2022-09-10  8:17 ` [PATCH 20/38] view: reduce ascii_html calls and {obuf} use Eric Wong
2022-09-10  8:17 ` [PATCH 21/38] view: html_footer: golf out a few lines Eric Wong
2022-09-10  8:17 ` [PATCH 22/38] view: html_footer: remove obuf dependency Eric Wong
2022-09-10  8:17 ` [PATCH 23/38] view: html_footer: avoid escaping " in a few places Eric Wong
2022-09-10  8:17 ` [PATCH 24/38] viewdiff: diff_hunk: shorten conditionals, slightly Eric Wong
2022-09-10  8:17 ` [PATCH 25/38] view: switch a few things to ctx->zmore Eric Wong
2022-09-10  8:17 ` [PATCH 26/38] www: drop {obuf} use entirely, for now Eric Wong
2022-09-10  8:17 ` [PATCH 27/38] www: switch to zadd for the majority of buffering Eric Wong
2022-09-10  8:17 ` [PATCH 28/38] www: use PerlIO::scalar (zfh) for buffering Eric Wong
2022-09-10  8:17 ` [PATCH 29/38] viewdiff: diff_before_or_after: avoid extra capture Eric Wong
2022-09-10  8:17 ` [PATCH 30/38] viewdiff: diff_header: shorten function, slightly Eric Wong
2022-09-10  8:17 ` [PATCH 31/38] www_static: switch to `print $zfh', and optimize Eric Wong
2022-09-10  8:17 ` [PATCH 32/38] httpd/async: describe which ->write subs it can call Eric Wong
2022-09-10  8:17 ` [PATCH 33/38] translate: support multiple buffer args Eric Wong
2022-09-10  8:17 ` [PATCH 34/38] gzip_filter: write: use multi-arg translate Eric Wong
2022-09-10  8:17 ` [PATCH 35/38] feed: new_html_i: switch from zmore to `print $zfh' Eric Wong
2022-09-10  8:17 ` [PATCH 36/38] mbox*: use multi-arg ->translate and ->write Eric Wong
2022-09-10  8:17 ` [PATCH 37/38] www_listing: switch to `print $zfh' Eric Wong
2022-09-10  8:17 ` [PATCH 38/38] viewvcs: " Eric Wong

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://public-inbox.org/README

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20220910081729.2011934-3-e@80x24.org \
    --to=e@80x24.org \
    --cc=meta@public-inbox.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://80x24.org/public-inbox.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).
diff --git a/lib/PublicInbox/GzipFilter.pm b/lib/PublicInbox/GzipFilter.pm
index 86d34183..75ba625e 100644
--- a/lib/PublicInbox/GzipFilter.pm
+++ b/lib/PublicInbox/GzipFilter.pm
@@ -140,8 +140,8 @@ sub zmore {
 	my $self = $_[0]; # $_[1] => input
 	http_out($self);
 	my $err;
-	for (1..$#_) {
-		$err = $self->{gz}->deflate($_[$_], $self->{zbuf});
+	for (delete $self->{obuf}, @_[1..$#_]) {
+		$err = $self->{gz}->deflate($_ // next, $self->{zbuf});
 		die "gzip->deflate: $err" if $err != Z_OK;
 	}
 	undef;
@@ -153,8 +153,9 @@ sub zflush ($;@) {
 	my $zbuf = delete $self->{zbuf};
 	my $gz = delete $self->{gz};
 	my $err;
-	for (1..$#_) { # it's a bug iff $gz is undef w/ $_[1..]
-		$err = $gz->deflate($_[$_], $zbuf);
+	# it's a bug iff $gz is undef w/ $obuf or $_[1..]
+	for (delete $self->{obuf}, @_[1..$#_]) {
+		$err = $gz->deflate($_ // next, $zbuf);
 		die "gzip->deflate: $err" if $err != Z_OK;
 	}
 	$gz // return ''; # not a bug, recursing on DS->write failure